# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/lotto/lottery_spell/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Lotto\\LotterySpell\\": "packages/lotto/lottery_spell/src",
            "Lotto\\LotterySpell\\Seeders\\": "packages/lotto/lottery_spell/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Lotto\LotterySpell\Providers\LotterySpellServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'LotterySpell'  => Lotto\LotterySpell\Facades\LotterySpell::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Lotto\\LotterySpell\\Seeders\\LotterySpellTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Lotto\LotterySpell\Providers\LotterySpellServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Lotto\LotterySpell\Providers\LotterySpellServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Lotto\LotterySpell\Providers\LotterySpellServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/lottery_spell/{modulename}

**User**

    http://path-to-route-folder/user/lottery_spell/{modulename}

**Public**

    http://path-to-route-folder/lottery_spells


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/lottery_spell/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/lottery_spell/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/lottery_spell/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/lottery_spell/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/lottery_spell/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/lottery_spell/{modulename}/{slug}
    METHOD: GET